/*
 * Copyright 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 3, as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "scope/store/package.h"


#include <cmath>
#include <sstream>


Libertine::Store::Package Libertine::Store::Package::
from_map(QVariantMap const& pkgMap)
{
  Package pkg;
  pkg.name = pkgMap["name"].toString().toStdString();
  pkg.summary = pkgMap["summary"].toString().toStdString();
  pkg.rating = pkgMap["rating"].toDouble();
  pkg.description = pkgMap["description"].toString().toStdString();
  pkg.icon = pkgMap["icon"].toString().toStdString();
  pkg.publisher = pkgMap["publisher"].toString().toStdString();
  pkg.website = pkgMap["website"].toString().toStdString();
  pkg.license = pkgMap["license"].toString().toStdString();
  pkg.id = pkgMap["id"].toString().toStdString();

  for (auto const& screenshot: pkgMap["screenshots"].toStringList())
  {
    pkg.screenshots.push_back(screenshot.toStdString());
  }

  return pkg;
}


QList<Libertine::Store::Package> Libertine::Store::Package::
from_map(QList<QVariantMap> const& pkgMap)
{
  QList<Package> pkgs;

  for (auto const& pkg: pkgMap)
  {
    pkgs << Package::from_map(pkg);
  }

  return pkgs;
}

std::string Libertine::Store::Package::
render_rating() const
{
  std::ostringstream ss;
  int rounded;

  if (rating < 0.0f) {
    rounded = 0;
  } else if (rating > 5.0f) {
    rounded = 5;
  } else {
    rounded = round(rating);
  }

  for (auto i = 0; i < rounded; ++i)
  {
    ss << "★";
  }
  for (auto j = rounded; j < 5; ++j)
  {
    ss << "☆";
  }
  return ss.str();
}
