/**
 * @file libertine_store/scope.cpp
 * @brief The implementation of the Libertine Store scope class.
 */
/*
 * Copyright 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 3, as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "scope/store/scope.h"

#include "scope/store/i18n.h"
#include "scope/store/preview.h"
#include "scope/store/query.h"
#include "scope/store/service_manager.h"


namespace usc = unity::scopes;


void Libertine::Store::Scope::
start(std::string const&)
{
  setlocale(LC_ALL, "");
  std::string translation_directory = ScopeBase::scope_directory()
                                    + "/../share/locale/";
  bindtextdomain(GETTEXT_PACKAGE, translation_directory.c_str());
}


usc::SearchQueryBase::UPtr Libertine::Store::Scope::
search(usc::CannedQuery const&    query,
       usc::SearchMetadata const& metadata)
{
  return usc::SearchQueryBase::UPtr(new Query(query, metadata, std::make_shared<ServiceManager>()));
}


usc::PreviewQueryBase::UPtr Libertine::Store::Scope::
preview(usc::Result const&         result,
        usc::ActionMetadata const& metadata)
{
  return usc::PreviewQueryBase::UPtr(new Preview(result, metadata, std::make_shared<ServiceManager>()));
}
