/*
 * Copyright 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, version 3, as published by the
 * Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "scope/store/service_manager.h"

#include <QtDBus>
#include <QDebug>
#include <QDBusMetaType>

namespace
{
constexpr auto SEARCH_CACHE_METHOD = "search";
constexpr auto APP_INFO_METHOD = "app_info";
constexpr auto LIBERTINE_SERVICE_DESTINATION = "com.canonical.libertine";
constexpr auto LIBERTINE_SERVICE_INTERFACE = "com.canonical.libertine.Store";
constexpr auto LIBERTINE_SERVICE_OBJECT = "/Store";
}


Libertine::Store::ServiceManager::
ServiceManager()
{
  qDBusRegisterMetaType<QList<QVariantMap > >();
}


Libertine::Store::Package Libertine::Store::ServiceManager::
app_info(const QString &app_id) const
{
  return Package::from_map(call<QVariantMap >(APP_INFO_METHOD, QVariant(app_id)));
}


QList<Libertine::Store::Package> Libertine::Store::ServiceManager::
search_cache(const QString &query) const
{
  return Package::from_map(call<QList<QVariantMap > >(SEARCH_CACHE_METHOD, QVariant(query)));
}


template<class T>
T Libertine::Store::ServiceManager::
call(QString const& method, QVariant const& arg1) const
{
  if (!valid())
  {
    qCritical() << "Cannot connect to D-Bus session bus.";
    return T{};
  }

  QDBusInterface iface(LIBERTINE_SERVICE_DESTINATION, LIBERTINE_SERVICE_OBJECT, LIBERTINE_SERVICE_INTERFACE, QDBusConnection::sessionBus());
  if (iface.isValid())
  {
    QDBusReply<T> response = iface.call(method, arg1);
    if (response.isValid())
    {
      return response.value();
    }

    qCritical() << "Call to " << method << " failed:" << qPrintable(response.error().message());
    return T{};
  }

  qCritical() << "No D-Bus interface found!";
  return T{};
}


bool Libertine::Store::ServiceManager::
valid() const
{
  return QDBusConnection::sessionBus().isConnected();
}

