# Copyright 2016 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import gi
gi.require_version('AppStream', '1.0')
from gi.repository import AppStream


def xstr(s):
	"""Converts anything to a string"""
	return str(s or "")


class AppStreamCache(object):
	"""AppStreamCache"""
	def __init__(self, config):
		super(AppStreamCache, self).__init__()
		self.config = config
		self.database = AppStream.Database()
		self.database.open()

	def search(self, query):
		packages = []
		for component in self.database.find_components(query, None):
			if component.is_valid():
				package = {}
				package["name"] = xstr(component.get_name())
				package["id"] = xstr(component.get_id())
				package["summary"] = xstr(component.get_summary())
				package["uri"] = xstr(component.get_url(AppStream.UrlKind.HOMEPAGE))
				package["rating"] = 3

				if len(component.get_icons()) > 0:
					package["icon"] = xstr(component.get_icons()[0].get_filename())
				packages.append(package)

		return packages

	def app_info(self, app_id):
		app = self.database.get_component_by_id(app_id)
		app_data = {}
		if app is not None and app.is_valid():
			app_data["name"] = xstr(app.get_name())
			app_data["id"] = xstr(app.get_id())
			app_data["summary"] = xstr(app.get_summary())
			app_data["website"] = xstr(app.get_url(AppStream.UrlKind.HOMEPAGE))
			app_data["rating"] = 3
			app_data["license"] = xstr(app.get_project_license())
			for screenshot in app.get_screenshots():
				if screenshot.is_valid() and screenshot.get_kind() is AppStream.ScreenshotKind.EXTRA:
					largest = None
					for image in screenshot.get_images():
						if image.get_kind() is AppStream.ImageKind.SOURCE and (largest is None or image.get_width() > largest.get_width()):
							largest = image
					if "screenshots" not in app_data:
						app_data["screenshots"] = []
					app_data["screenshots"].append(largest.get_url())

			app_data["description"] = xstr(app.get_description())

			if len(app.get_icons()) > 0:
				app_data["icon"] = xstr(app.get_icons()[0].get_filename())

		return app_data
