# Copyright 2016 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import dbus
import dbus.service
import logging
from libertine import apt
from libertine import appstream
from dbus.mainloop.glib import DBusGMainLoop


LIBERTINE_SERVICE_NAME = "com.canonical.libertine"
LIBERTINE_STORE_INTERFACE = "com.canonical.libertine.Store"
LIBERTINE_STORE_PATH = "/Store"

log = logging.getLogger("Libertine")


class Service(dbus.service.Object):

    def __init__(self, config):
        log.info("creating service")
        self.cache = appstream.AppStreamCache(config)
        DBusGMainLoop(set_as_default=True)
        try:
            bus_name = dbus.service.BusName(LIBERTINE_SERVICE_NAME,
                                            bus=dbus.SessionBus(),
                                            do_not_queue=True)
        except dbus.exceptions.NameExistsException:
            log.warning("service is already running")
            raise
        super().__init__(bus_name, LIBERTINE_STORE_PATH)

    @dbus.service.method(LIBERTINE_STORE_INTERFACE,
                         out_signature='as')
    def get_categories(self):
        log.debug("get_categories() called")
        categories = [ "Fun", "Work", "Pink" ]
        return categories

    @dbus.service.method(LIBERTINE_STORE_INTERFACE,
                         out_signature='as')
    def get_featured(self):
        log.debug("get_featured() called")
        return []

    @dbus.service.method(LIBERTINE_STORE_INTERFACE,
                         out_signature='as')
    def get_popular(self):
        log.debug("get_popular() called")
        return []

    @dbus.service.method(LIBERTINE_STORE_INTERFACE,
                         in_signature='s',
                         out_signature='aa{sv}')
    def search(self, search_string):
        log.debug("search('{}') called".format(search_string))
        return self.cache.search(search_string)

    @dbus.service.method(LIBERTINE_STORE_INTERFACE,
                         in_signature='s',
                         out_signature='a{sv}')
    def app_info(self, app_id):
        log.debug("app_info('{}') called".format(app_id))
        return self.cache.app_info(app_id)

    @dbus.service.signal(LIBERTINE_STORE_INTERFACE,
                         signature='su')
    def updating(self, target, percent):
        log.debug("emit updating('{}', {})".format(target, percent))
